@@ -9,8 +9,8 @@
 #'Code \tab Description\cr
 #'INF \tab Information \cr
 #'PHY \tab Physical \cr
-#'INM \tab Inorganics, Major, Metals (major cations) \cr
-#'INN \tab Inorganics, Major, Non-metals (major anions) \cr
+#'INM \tab Inorganics, Major, Metals \cr
+#'INN \tab Inorganics, Major, Non-metals \cr
 #'NUT \tab Nutrient \cr
 #'MBI \tab Microbiological \cr
 #'BIO \tab Biological \cr
@@ -20,9 +20,12 @@
 #'OPE \tab Organics, pesticide \cr
 #'OPC \tab Organics, PCBs \cr
 #'OOT \tab Organics, other \cr
-#'RAD \tab Radiochemical \cr
+#'RAD \tab Radiochemistry \cr
 #'SED \tab Sediment \cr
 #'POP \tab Population/community \cr
+#'OTH \tab  Other \cr
+#'HAB \tab  Habitat \cr
+#'ISO \tab  Stable Isotopes \cr
 #'}
 #'If more than one parameter group is requested, only sites that data for all requested groups are returned.
 #'
@@ -94,14 +97,14 @@
 #' groups <- c("NUT","OPE")
 #' rawNWISNutOpe <- readNWISqw(site_ids,groups,
 #'           startDate,endDate) 
-#' rawNWISOpe <- readNWISqw(site_ids,"OPE",
-#'           startDate,endDate) 
+#' rawISO <- readNWISqw("413144073115701", "ISO") 
 #'          } 
 readNWISqw <- function (siteNumbers,parameterCd,startDate="",endDate="",
                         expanded=TRUE,reshape=FALSE,tz="UTC"){  
   
   pgrp <- c("INF", "PHY", "INM", "INN", "NUT", "MBI", "BIO", "IMM", "IMN", "TOX",
-                           "OPE", "OPC", "OOT", "RAD", "XXX", "SED", "POP")
+            "OPE", "OPC", "OOT", "RAD", "XXX", "SED", "POP",
+            "ISO", "OTH", "HAB")
 
   if(any(parameterCd == "all") | any(parameterCd == "All") ){
     
